summaryrefslogtreecommitdiffstats
path: root/kaudiocreator/jobqueimp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kaudiocreator/jobqueimp.cpp')
-rw-r--r--kaudiocreator/jobqueimp.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kaudiocreator/jobqueimp.cpp b/kaudiocreator/jobqueimp.cpp
index fc580a29..8ca6d087 100644
--- a/kaudiocreator/jobqueimp.cpp
+++ b/kaudiocreator/jobqueimp.cpp
@@ -46,11 +46,11 @@
/**
* Constructor, set up signals.
* @param tqparent - tqparent widget
* @param name - widget name
*/
-JobQueImp::JobQueImp( TQWidget* tqparent, const char* name) :
- JobQue(tqparent,name),highestNumber(DEFAULT_HIGHEST_NUMBER), currentId(0){
+JobQueImp::JobQueImp( TQWidget* parent, const char* name) :
+ JobQue(parent,name),highestNumber(DEFAULT_HIGHEST_NUMBER), currentId(0){
connect(removeSelected,TQT_SIGNAL(clicked()), this, TQT_SLOT( removeSelectedJob()));
connect(removeAll, TQT_SIGNAL(clicked()), this, TQT_SLOT(removeAllJobs()));
connect(removeDoneJobs, TQT_SIGNAL(clicked()), this, TQT_SLOT(clearDoneJobs()));
@@ -303,7 +303,7 @@ void QueListViewItem::paintCell (TQPainter * p,const TQColorGroup &cg,int column
/**
* Header for built in treelist item so we can have a progress bar in them.
*/
-QueListViewItem::QueListViewItem(TQListView *tqparent, const TQString id, const TQString p , const TQString name, const TQString d, const TQString e) : TQListViewItem(tqparent, id, p, name,d,e), percentDone(0), progressing(false) {
+QueListViewItem::QueListViewItem(TQListView *parent, const TQString id, const TQString p , const TQString name, const TQString d, const TQString e) : TQListViewItem(parent, id, p, name,d,e), percentDone(0), progressing(false) {
}
#include "jobqueimp.moc"
@@ -46,11 +46,11 @@
/**
* Constructor, set up signals.
- * @param tqparent - tqparent widget
+ * @param parent - parent widget
* @param name - widget name
*/